Module: Kejot
- Defined in:
- lib/kejot.rb,
lib/kejot/version.rb
Defined Under Namespace
Classes: Generator
Constant Summary collapse
- SPELL_SET1 =
%w(accurate sufficient ugly useful immediate entire healthy hot efficient dramatic)
- SPELL_SET2 =
%w(punch kick attack blow smash strike smack cut poke stab)
- VERSION =
"0.1.1"